=======================
Software Implementation
=======================

.. contents:: `Contents`
    :depth: 3
    :local:

-----------------------------------
Implementation for mlx.traceability
-----------------------------------

TraceableItem
=============

.. item:: IMPL-TRACEABLE_ITEM
    :fulfills: DESIGN-ITEMIZE

    .. automodule:: mlx.traceable_item
        :members:
        :show-inheritance:

TraceableCollection
===================

.. item:: IMPL-TRACEABLE_COLLECTION

    .. automodule:: mlx.traceable_collection
        :members:
        :show-inheritance:

TraceabilityException
=====================

.. item:: IMPL-TRACEABILITY_EXCEPTION

    .. automodule:: mlx.traceability_exception
        :members:
        :show-inheritance:

Design coverage
===============

.. item-matrix:: Trace implementation to design
    :source: IMPL
    :target: DESIGN
    :sourcetitle: Implementation
    :targettitle: Design
    :nocaptions:
    :stats:

